@@ -34,9 +34,9 @@ typedef RE_UINT32 (*RE_GetPropertyFunc)(RE_UINT32 codepoint);
 
 #define RE_PROP_GC 0x1E
 #define RE_PROP_CASED 0xA
-#define RE_PROP_UPPERCASE 0x57
-#define RE_PROP_LOWERCASE 0x34
-#define RE_PROP_SCX 0x51
+#define RE_PROP_UPPERCASE 0x5B
+#define RE_PROP_LOWERCASE 0x38
+#define RE_PROP_SCX 0x55
 
 #define RE_PROP_C 30
 #define RE_PROP_L 31
@@ -95,16 +95,16 @@ typedef RE_UINT32 (*RE_GetPropertyFunc)(RE_UINT32 codepoint);
 #define RE_PROP_CNTRL 0x1E0001
 #define RE_PROP_DIGIT 0x1E0009
 #define RE_PROP_GRAPH 0x1F0001
-#define RE_PROP_LOWER 0x340001
-#define RE_PROP_PRINT 0x4C0001
-#define RE_PROP_SPACE 0x5A0001
-#define RE_PROP_UPPER 0x570001
-#define RE_PROP_WORD 0x5B0001
-#define RE_PROP_XDIGIT 0x5D0001
-#define RE_PROP_POSIX_ALNUM 0x470001
-#define RE_PROP_POSIX_DIGIT 0x480001
-#define RE_PROP_POSIX_PUNCT 0x490001
-#define RE_PROP_POSIX_XDIGIT 0x4A0001
+#define RE_PROP_LOWER 0x380001
+#define RE_PROP_PRINT 0x500001
+#define RE_PROP_SPACE 0x5E0001
+#define RE_PROP_UPPER 0x5B0001
+#define RE_PROP_WORD 0x5F0001
+#define RE_PROP_XDIGIT 0x610001
+#define RE_PROP_POSIX_ALNUM 0x4B0001
+#define RE_PROP_POSIX_DIGIT 0x4C0001
+#define RE_PROP_POSIX_PUNCT 0x4D0001
+#define RE_PROP_POSIX_XDIGIT 0x4E0001
 
 #define RE_WBREAK_OTHER 0
 #define RE_WBREAK_LF 1
@@ -178,26 +178,31 @@ typedef RE_UINT32 (*RE_GetPropertyFunc)(RE_UINT32 codepoint);
 #define RE_LBREAK_JV 26
 #define RE_LBREAK_JT 27
 #define RE_LBREAK_NONSTARTER 28
-#define RE_LBREAK_ZWSPACE 29
-#define RE_LBREAK_ZWJ 30
-#define RE_LBREAK_BREAKBOTH 31
-#define RE_LBREAK_INSEPARABLE 32
-#define RE_LBREAK_WORDJOINER 33
-#define RE_LBREAK_IDEOGRAPHIC 34
-#define RE_LBREAK_EBASE 35
-#define RE_LBREAK_CONDITIONALJAPANESESTARTER 36
-#define RE_LBREAK_H2 37
-#define RE_LBREAK_H3 38
-#define RE_LBREAK_SURROGATE 39
-#define RE_LBREAK_CONTINGENTBREAK 40
-#define RE_LBREAK_REGIONALINDICATOR 41
-#define RE_LBREAK_EMODIFIER 42
+#define RE_LBREAK_AKSARA 29
+#define RE_LBREAK_VIRAMA 30
+#define RE_LBREAK_IDEOGRAPHIC 31
+#define RE_LBREAK_AKSARASTART 32
+#define RE_LBREAK_VIRAMAFINAL 33
+#define RE_LBREAK_ZWSPACE 34
+#define RE_LBREAK_ZWJ 35
+#define RE_LBREAK_BREAKBOTH 36
+#define RE_LBREAK_INSEPARABLE 37
+#define RE_LBREAK_WORDJOINER 38
+#define RE_LBREAK_EBASE 39
+#define RE_LBREAK_CONDITIONALJAPANESESTARTER 40
+#define RE_LBREAK_H2 41
+#define RE_LBREAK_H3 42
+#define RE_LBREAK_SURROGATE 43
+#define RE_LBREAK_CONTINGENTBREAK 44
+#define RE_LBREAK_AKSARAPREBASE 45
+#define RE_LBREAK_REGIONALINDICATOR 46
+#define RE_LBREAK_EMODIFIER 47
 
-extern char* re_strings[1474];
-extern RE_Property re_properties[177];
-extern RE_PropertyValue re_property_values[1619];
+extern char* re_strings[1506];
+extern RE_Property re_properties[183];
+extern RE_PropertyValue re_property_values[1651];
 extern RE_UINT16 re_expand_on_folding[104];
-extern RE_GetPropertyFunc re_get_property[96];
+extern RE_GetPropertyFunc re_get_property[100];
 
 RE_UINT32 re_get_alphabetic(RE_UINT32 codepoint);
 RE_UINT32 re_get_alphanumeric(RE_UINT32 codepoint);
@@ -239,11 +244,15 @@ RE_UINT32 re_get_hangul_syllable_type(RE_UINT32 codepoint);
 RE_UINT32 re_get_hex_digit(RE_UINT32 codepoint);
 RE_UINT32 re_get_horiz_space(RE_UINT32 codepoint);
 RE_UINT32 re_get_hyphen(RE_UINT32 codepoint);
+RE_UINT32 re_get_id_compat_math_continue(RE_UINT32 codepoint);
+RE_UINT32 re_get_id_compat_math_start(RE_UINT32 codepoint);
 RE_UINT32 re_get_id_continue(RE_UINT32 codepoint);
 RE_UINT32 re_get_ideographic(RE_UINT32 codepoint);
 RE_UINT32 re_get_ids_binary_operator(RE_UINT32 codepoint);
 RE_UINT32 re_get_id_start(RE_UINT32 codepoint);
 RE_UINT32 re_get_ids_trinary_operator(RE_UINT32 codepoint);
+RE_UINT32 re_get_ids_unary_operator(RE_UINT32 codepoint);
+RE_UINT32 re_get_indic_conjunct_break(RE_UINT32 codepoint);
 RE_UINT32 re_get_indic_positional_category(RE_UINT32 codepoint);
 RE_UINT32 re_get_indic_syllabic_category(RE_UINT32 codepoint);
 RE_UINT32 re_get_join_control(RE_UINT32 codepoint);
